@@ -163,16 +163,17 @@ def manhattanplot(data, chrom="#CHROM", pos="POS", pv="P", snp="ID", logp=True,
         >>> df = df.dropna(how="any", axis=0)  # clean data
         >>> ax = manhattanplot(data=df)
 
-    Plot a basic manhattan plot with vertical xtick labels:
+    Plot a basic manhattan plot with horizontal xtick labels and save the plot
+    to a file name "manhattan.png":
 
     .. plot::
         :context: close-figs
 
         >>> xtick = set(list(map(str, range(1, 15))) + ['16', '18', '20', '22', 'X'])
         >>> manhattanplot(data=df, xlabel="Chromosome", ylabel=r"$-log_{10}{(P)}$",
-        ...               xtick_label_set=xtick)
+        ...               xtick_label_set=xtick, figname="manhattan.png")
 
-    Add a horizotal at y position=3 line with linestyle="--" and lingwidth=1.3
+    Add a horizontal at y position=3 line with linestyle="--" and lingwidth=1.3
     across the axis:
 
     .. plot::
@@ -184,6 +185,17 @@ def manhattanplot(data, chrom="#CHROM", pos="POS", pv="P", snp="ID", logp=True,
         ...               ylabel=r"$-log_{10}{(P)}$",
         ...               xtick_label_set = xtick)
 
+    Rotate the x-axis ticklabel by setting ``xticklabel_kws``:
+
+    .. plot::
+        :context: close-figs
+
+        >>> manhattanplot(data=df,
+        ...               hline_kws={"y": 3, "linestyle": "--", "lw": 1.3},
+        ...               xlabel="Chromosome",
+        ...               ylabel=r"$-log_{10}{(P)}$",
+        ...               xticklabel_kws={"rotation": "vertical"})
+
     Plot a better one with genome-wide significant mark and annotate the Top SNP and save
     the figure to "output_manhattan_plot.png":
 
@@ -208,8 +220,8 @@ def manhattanplot(data, chrom="#CHROM", pos="POS", pv="P", snp="ID", logp=True,
         ...                             "xycoords": "data",
         ...                             "xytext": (15, +15),
         ...                             "textcoords": "offset points",
-        ...                             "bbox": dict(boxstyle="round", alpha=0.2),  # dict(boxstyle="round", fc="0.8")
-        ...                             "arrowprops": dict(arrowstyle="->",  # "-|>"
+        ...                             "bbox": dict(boxstyle="round", alpha=0.2), 
+        ...                             "arrowprops": dict(arrowstyle="->",
         ...                                                connectionstyle="angle,angleA=0,angleB=80,rad=10",
         ...                                                alpha=0.6, relpos=(0, 0))},
         ...               dpi=300,  # set the resolution of plot figure
@@ -254,7 +266,7 @@ def manhattanplot(data, chrom="#CHROM", pos="POS", pv="P", snp="ID", logp=True,
     xs_by_id = []  # use for collecting chromosome's position on x-axis
     x, y, c = [], [], []
     sign_snp_sites = []
-    for seqid, group_data in data.groupby(chrom, sort=False):  # keep the raw order of chromosome
+    for seqid, group_data in data.groupby(by=chrom, sort=False):  # keep the raw order of chromosome
 
         if (CHR is not None) and (seqid != CHR):
             continue
